import sys
import typing

GenericType = typing.TypeVar("GenericType")


def generate(context, space_type, use_fallback_keys, use_reset):
    ''' 

    '''

    pass
